@@ -29,12 +29,21 @@ to a file or the standard output.
 
 Create a new MARC exporter of the given type. Currently we support:
 
-    USMARC    alias for ISO, B<deprecated, will be removed in future version>
-    ISO       L<Catmandu::Importer::MARC::ISO>
-    XML       L<Catmandu::Exporter::MARC::XML>
-    MARCMaker L<Catmandu::Exporter::MARC::MARCMaker>
-    MiJ       L<Catmandu::Exporter::MARC::MiJ> (Marc in Json)
-    ALEPHSEQ  L<Catmandu::Exporter::MARC::ALEPHSEQ>
+=over
+
+=item * USMARC: alias for ISO, B<deprecated, will be removed in future version>
+
+=item * ISO: L<Catmandu::Importer::MARC::ISO>
+
+=item * XML: L<Catmandu::Exporter::MARC::XML>
+
+=item * MARCMaker: L<Catmandu::Exporter::MARC::MARCMaker>
+
+=item * MiJ: L<Catmandu::Exporter::MARC::MiJ> (Marc in Json)
+
+=item * ALEPHSEQ: L<Catmandu::Exporter::MARC::ALEPHSEQ>
+
+=back
 
 =item file
 
@@ -67,7 +76,7 @@ package Catmandu::Exporter::MARC;
 use Catmandu::Sane;
 use Moo;
 
-our $VERSION = '1.00_02';
+our $VERSION = '1.00_03';
 
 has type           => (is => 'ro' , default => sub { 'ISO' });
 has _exporter      => (is => 'ro' , lazy => 1 , builder => '_build_exporter' , handles => 'Catmandu::Exporter');
