@@ -4,7 +4,7 @@ Catmandu::Importer::MARC - Package that imports MARC data
 
 =head1 SYNOPSIS
 
-    # From the command line
+    # From the command line convert MARC to JSON mapping 245a to a title
     $ catmandu convert MARC --fix "marc_map('245a','title')" < /foo/bar.mrc
 
     # From Perl
@@ -70,15 +70,27 @@ Read more about processing data with Catmandu on the wiki: L<https://github.com/
 
 Create a new MARC importer of the given type. Currently we support:
 
-    USMARC    alias for ISO, B<deprecated, will be removed in future version>
-    ISO       L<Catmandu::Importer::MARC::ISO>
-    MicroLIF  L<Catmandu::Importer::MARC::MicroLIF>
-    MARCMaker L<Catmandu::Importer::MARC::MARCMaker>
-    MiJ       L<Catmandu::Importer::MARC::MiJ>
-    XML       L<Catmandu::Importer::MARC::XML>
-    RAW       L<Catmandu::Importer::MARC::RAW>
-    Lint      L<Catmandu::Importer::MARC::Lint>
-    ALEPHSEQ  L<Catmandu::Importer::MARC::ALEPHSEQ>
+=over
+
+=item * USMARC: alias for ISO, B<deprecated, will be removed in future version>
+
+=item * ISO: L<Catmandu::Importer::MARC::ISO>
+
+=item * MicroLIF: L<Catmandu::Importer::MARC::MicroLIF>
+
+=item * MARCMaker: L<Catmandu::Importer::MARC::MARCMaker>
+
+=item * MiJ: L<Catmandu::Importer::MARC::MiJ>
+
+=item * XML: L<Catmandu::Importer::MARC::XML>
+
+=item * RAW: L<Catmandu::Importer::MARC::RAW>
+
+=item * Lint: L<Catmandu::Importer::MARC::Lint>
+
+=item * ALEPHSEQ: L<Catmandu::Importer::MARC::ALEPHSEQ>
+
+=back
 
 =item file
 
@@ -115,7 +127,7 @@ use Catmandu::Sane;
 use Catmandu::Util;
 use Moo;
 
-our $VERSION = '1.00_02';
+our $VERSION = '1.00_03';
 
 has type           => (is => 'ro' , default => sub { 'ISO' });
 has _importer      => (is => 'ro' , lazy => 1 , builder => '_build_importer' , handles => ['generator']);
